package filesengine

import (
	"context"
	"fmt"

	"git.optclblast.xyz/draincloud/draincloud-core/internal/storage"
	"git.optclblast.xyz/draincloud/draincloud-core/internal/storage/models/files"
)

type FilesEngine struct {
	blobStorage storage.BlobStorage
	metaStorage storage.MetaStorage
}

func NewFilesEngine(
	blobStorage storage.BlobStorage,
	metaStorage storage.MetaStorage,
) *FilesEngine {
	return &FilesEngine{
		blobStorage: blobStorage,
		metaStorage: metaStorage,
	}
}

type File struct {
	Name   string
	UserID int64
	Ext    string
	Type   string
	Size   int64
	Data   []byte
}

// TODO save file
func (e *FilesEngine) SaveFile(
	ctx context.Context,
	file File,
) (int64, error) {
	fileID, err := e.metaStorage.SaveMetadata(ctx, files.FileMetadata{})
	if err != nil {
		return -1, fmt.Errorf("failed to create new file metadata: %w", err)
	}

	if err = e.blobStorage.SaveBlob(ctx, fileID, file.Data); err != nil {
		return -1, fmt.Errorf("failed to save file data: %w", err)
	}

	return fileID, nil
}
